from flask import Flask, render_template, request, redirect, session
import socket
import logging
import platform

if  'Windows' in platform.platform():
    path = ''
    logging.basicConfig(filename=rf'{path}error.log', encoding='utf-8', level=logging.DEBUG)
    logging.debug('Window, Logging Debug')
else:       
    path = r'/volume1/web/codeLocker/web_flask/'
    logging.basicConfig(filename=rf'{path}error.log', encoding='utf-8', level=logging.DEBUG)
    logging.debug('Linux, Logging Debug')

app = Flask(__name__)
app.secret_key = 'BFEuTTCrEQEIyi16bq7A'

HOSTS = {"192.168.234.161":"Haustür",
         "192.168.234.165":"Carport",
         "192.168.234.167":"Gartentür"}
Light = ["192.168.234.161", "192.168.234.165" ]
PORT = 2340  

def getData(request):
    data = []
    with socket.socket(socket.AF_INET, socket.SOCK_STREAM) as s:
        HOST = session['HOST']
        try:
            s.connect((HOST,PORT))
            s.settimeout(2)
            for r in request:
                s.sendall((f'{r}\r\n').encode())
                try:
                    recv = s.recv(1024)
                except:
                    data.append(['TimeOut'])
                    logging.exception(f'Timeout r: {r}')
                    continue
                # for e in recv.decode().replace('\r\n','').split('\r'):
                for e in recv.decode().replace('\r\r','\r').split('\r\n'):
                    d = e.split(':')
                    if len(d) > 1:
                        data.append([d[0],d[1]])
                    else:
                        try: 
                            recv = s.recv(1024)
                            e += recv.decode().replace('\r\n','')
                            d = e.split(':') 
                            if len(d) > 1:
                                data.append([d[0],d[1]])
                            else:
                                if len(data) < 1:
                                    data.append(['Result',e])
                        except:
                            logging.exception(f'Result e: {e}')
                            if len(data) < 1:
                                data.append(['Result',e])
        except:
            logging.exception(rf'Error Door Connection: {HOST}')
            logging.debug(f'Request: {request}')
        finally:
            s.close()      
    return data

@app.route('/')
def index():
    if request.args.get('host'):
        session['HOST'] = request.args.get('host')
    if not 'HOST' in session:
        HOST = list(HOSTS.keys())[0]
        session['HOST'] = HOST
    if session['HOST'] in Light:
        data = getData(['TEMP_IN','TEMP_OUT','READ_LIGHT'])
    else:
        data = getData(['TEMP_IN','TEMP_OUT'])
    return (render_template('index.html', 
        # data=getData(['TEMP_IN','TEMP_OUT','READ_LIGHT']),
        data=data,
        host = session['HOST'],
        hosts = HOSTS ))

@app.route("/open", methods = ['POST'])
def open():
    code = request.form['code']
    if 'openDoor' in list(request.form):
        res = getData([f'OPEN_DOOR:{code}'])
    return(redirect('/'))
    
@app.route('/conf', methods = ['POST'])
def conf():
    code = request.form['code']
    if session['HOST'] in Light:
        data = getData(['TEMP_IN','TEMP_OUT','READ_LIGHT'])
    else:
        data = getData(['TEMP_IN','TEMP_OUT'])
    return(render_template('conf.html',
        data=data,
        wait=getData([f'READ_WAIT:{code}']),
        light = getData(['GET_DARK','GET_LIGHT']),
        timeout = getData([f'GET_OPEN:{code}',f'GET_MIN_WAIT:{code}',f'GET_MAX_WAIT:{code}']),
        host = session['HOST'],
        hosts = HOSTS,        
        code = code))

@app.route('/writeConf', methods = ['POST'])
def writeConf():
    i = list(request.form)
    code = request.form['code']    
    if request.form["Min"]:
        res = getData([f'SET_MIN_WAIT:{code}:{request.form["Min"]}'])
        logging.debug(f'SET_MIN_WAIT: {res}')
    elif request.form["Max"]:
        res = getData([f'SET_MAX_WAIT:{code}:{request.form["Max"]}'])
        logging.debug(f'SET_MAX_WAIT: {res}')
    elif request.form["Open"]:
        res = getData([f'SET_OPEN:{code}:{request.form["Open"]}'])
        logging.debug(f'SET_OPEN: {res}')
    elif 'SET_Dark' in i :
        if request.form['SET_Dark'] == 'on':
            res = getData([f'SET_DARK:{code}'])
            logging.debug(f'SET_DARK: {res}')
    elif 'SET_Light' in i :
        if request.form['SET_Light'] == 'on':
            res = getData([f'SET_Light:{code}'])
            logging.debug(f'SET_Light: {res}')
    return(conf())

@app.route('/lock', methods = ['POST'])
def lock():
    i = list(request.form)
    if 'lock' in i:
        res = getData([f'LOCK_DOOR:{request.form["code"]}'])
        logging.debug(f'Lock: {res}')
    elif 'resync' in i:
        res = getData([f'RE_SYNC:{request.form["code"]}'])        
        logging.debug(f'RE_SYNC: {res}')
    return(conf())

@app.route('/ligth', methods = ['POST'])
def ligth():
    i = list(request.form)
    if 'LIGHT_ON' in i:
        res = getData(['LIGHT_ON'])
        logging.debug(f'LIGHT_ON: {res}')
    elif 'LIGHT_OFF' in i:
        res = getData(['LIGHT_OFF'])        
        logging.debug(f'LIGHT_OFF: {res}')
    return(conf())

@app.route('/codes', methods = ['GET'])
def get_codes():
    return(render_template('codes.html'))

@app.route('/codes', methods = ['POST'])
def post_codes():
    i = list(request.form)
    code = request.form["code"]
    if "readCode" in i:
        pass
    elif "DEL_CODE" in i:
        res = getData([f'DEL_CODE:{code}:{request.form["nrCode"]}'])
    elif "NEW_CODE" in i:
        res = getData([f'NEW_CODE:{code}:{request.form["newcode"]}'])
    else:
        logging.debug(f"post_codes, unknown input: {i}")
    data = getData([f'READ_CODE:{request.form["code"]}'])
    return(render_template('codes.html',
        data=data,code=code,
        host = session['HOST'],
        hosts = HOSTS))

if __name__ == '__main__':
    app.run(debug=True)